From 676ac33442c98d930bd31faab52f7356f1ec715f Mon Sep 17 00:00:00 2001
From: Joel Aaron Cohen <aaron@assonance.org>
Date: Sat, 28 Dec 2013 10:15:15 -0500
Subject: [PATCH] Don't initialize classes during import

---
 src/jvm/clojure/lang/Compiler.java              | 6 +++---
 src/jvm/clojure/lang/RT.java                    | 2 +-
 test/clojure/test_clojure/genclass.clj          | 1 +
 test/clojure/test_clojure/genclass/examples.clj | 2 ++
 4 files changed, 7 insertions(+), 4 deletions(-)

diff --git a/src/jvm/clojure/lang/Compiler.java b/src/jvm/clojure/lang/Compiler.java
index c961f2f..1b6feab 100644
--- a/src/jvm/clojure/lang/Compiler.java
+++ b/src/jvm/clojure/lang/Compiler.java
@@ -694,7 +694,7 @@ public static class KeywordExpr extends LiteralExpr{
 
 public static class ImportExpr implements Expr{
 	public final String c;
-	final static Method forNameMethod = Method.getMethod("Class forName(String)");
+	final static Method forNameMethod = Method.getMethod("Class classForNameNonLoading(String)");
 	final static Method importClassMethod = Method.getMethod("Class importClass(Class)");
 	final static Method derefMethod = Method.getMethod("Object deref()");
 
@@ -704,7 +704,7 @@ public static class ImportExpr implements Expr{
 
 	public Object eval() {
 		Namespace ns = (Namespace) RT.CURRENT_NS.deref();
-		ns.importClass(RT.classForName(c));
+		ns.importClass(RT.classForNameNonLoading(c));
 		return null;
 	}
 
@@ -713,7 +713,7 @@ public static class ImportExpr implements Expr{
 		gen.invokeVirtual(VAR_TYPE, derefMethod);
 		gen.checkCast(NS_TYPE);
 		gen.push(c);
-		gen.invokeStatic(CLASS_TYPE, forNameMethod);
+		gen.invokeStatic(RT_TYPE, forNameMethod);
 		gen.invokeVirtual(NS_TYPE, importClassMethod);
 		if(context == C.STATEMENT)
 			gen.pop();
diff --git a/src/jvm/clojure/lang/RT.java b/src/jvm/clojure/lang/RT.java
index b247ccb..0aa00ef 100644
--- a/src/jvm/clojure/lang/RT.java
+++ b/src/jvm/clojure/lang/RT.java
@@ -2071,7 +2071,7 @@ static public Class classForName(String name) {
 		}
 }
 
-static Class classForNameNonLoading(String name) {
+static public Class classForNameNonLoading(String name) {
 	try
 		{
 		return Class.forName(name, false, baseLoader());
diff --git a/test/clojure/test_clojure/genclass.clj b/test/clojure/test_clojure/genclass.clj
index 8fe893b..837fcb1 100644
--- a/test/clojure/test_clojure/genclass.clj
+++ b/test/clojure/test_clojure/genclass.clj
@@ -10,6 +10,7 @@
       :author "Stuart Halloway, Daniel Solano Gómez"}
   clojure.test-clojure.genclass
   (:use clojure.test clojure.test-helper)
+  (:require clojure.test_clojure.genclass.examples)
   (:import [clojure.test_clojure.genclass.examples
             ExampleClass
             ExampleAnnotationClass
diff --git a/test/clojure/test_clojure/genclass/examples.clj b/test/clojure/test_clojure/genclass/examples.clj
index 5b2a62a..f30c38a 100644
--- a/test/clojure/test_clojure/genclass/examples.clj
+++ b/test/clojure/test_clojure/genclass/examples.clj
@@ -29,6 +29,8 @@
   [_ o i]
   "foo with o, i")
 
+(declare -toString)
+
 (gen-class :name ^{Deprecated {}
                    SuppressWarnings ["Warning1"] ; discarded
                    java.lang.annotation.Target []}
-- 
1.8.4.msysgit.0

